@@ -2,7 +2,7 @@
 #
 # Apache::Session::Lock::File
 # flock(2) locking for Apache::Session
-# Copyright(c) 1998, 1999, 2000, 2004 Jeffrey William Baker (jwbaker@acm.org)
+# Copyright(c) 1998, 1999, 2000 Jeffrey William Baker (jwbaker@acm.org)
 # Distribute under the Artistic License
 #
 ############################################################################
@@ -15,7 +15,7 @@ use Fcntl qw(:flock);
 use Symbol;
 use vars qw($VERSION);
 
-$VERSION = '1.04';
+$VERSION = '1.00';
 
 $Apache::Session::Lock::File::LockDirectory = '/tmp';
 
@@ -26,19 +26,10 @@ sub new {
 }
 
 sub acquire_read_lock  {
-    if ($^O eq 'MSWin32' or $^O eq 'cygwin') {
-        #Windows cannot escalate lock, so all locks will be exclusive
-        return &acquire_write_lock;
-    }
-    #Works for acquire_read_lock => acquire_write_lock => release_all_locks
-    #This hack does not support release_read_lock
-    #Changed by Alexandr Ciornii, 2006-06-21
-
     my $self    = shift;
     my $session = shift;
     
     return if $self->{read};
-    #does not support release_read_lock
 
     if (!$self->{opened}) {
         my $fh = Symbol::gensym();
@@ -46,17 +37,13 @@ sub acquire_read_lock  {
         my $LockDirectory = $session->{args}->{LockDirectory} || 
             $Apache::Session::Lock::File::LockDirectory;
             
-        open($fh, "+>".$LockDirectory."/Apache-Session-".$session->{data}->{_session_id}.".lock") || die "Could not open file (".$LockDirectory."/Apache-Session-".$session->{data}->{_session_id}.".lock) for writing: $!";
+        open($fh, "+>".$LockDirectory."/Apache-Session-".$session->{data}->{_session_id}.".lock") || die $!;
 
         $self->{fh} = $fh;
         $self->{opened} = 1;
     }
         
-    if (!$self->{write}) {
-     #acquiring read lock, when write lock is in effect will clear write lock
-     flock($self->{fh}, LOCK_SH) || die "Cannot lock: $!";
-    }
-
+    flock($self->{fh}, LOCK_SH);
     $self->{read} = 1;
 }
 
@@ -72,28 +59,25 @@ sub acquire_write_lock {
         my $LockDirectory = $session->{args}->{LockDirectory} || 
             $Apache::Session::Lock::File::LockDirectory;
             
-        open($fh, "+>".$LockDirectory."/Apache-Session-".$session->{data}->{_session_id}.".lock") || die "Could not open file (".$LockDirectory."/Apache-Session-".$session->{data}->{_session_id}.".lock) for writing: $!";
+        open($fh, "+>".$LockDirectory."/Apache-Session-".$session->{data}->{_session_id}.".lock") || die $!;
 
         $self->{fh} = $fh;
         $self->{opened} = 1;
     }
-    
-    flock($self->{fh}, LOCK_EX) || die "Cannot lock: $!";
+        
+    flock($self->{fh}, LOCK_EX);    
     $self->{write} = 1;
 }
 
 sub release_read_lock  {
-    if ($^O eq 'MSWin32' or $^O eq 'cygwin') {
-        die "release_read_lock is not supported on Win32 or Cygwin";
-    }
     my $self    = shift;
     my $session = shift;
     
-    die "No read lock to release in release_read_lock" unless $self->{read};
+    die unless $self->{read};
     
     if (!$self->{write}) {
-        flock($self->{fh}, LOCK_UN) || die "Cannot unlock: $!";
-        close $self->{fh} || die "Could no close file: $!";
+        flock($self->{fh}, LOCK_UN);
+        close $self->{fh} || die $!;
         $self->{opened} = 0;
     }
     
@@ -104,14 +88,14 @@ sub release_write_lock {
     my $self    = shift;
     my $session = shift;
     
-    die "No write lock acquired" unless $self->{write};
+    die unless $self->{write};
     
     if ($self->{read}) {
-        flock($self->{fh}, LOCK_SH) || die "Cannot lock: $!";
+        flock($self->{fh}, LOCK_SH);
     }
     else {
-        flock($self->{fh}, LOCK_UN) || die "Cannot unlock: $!";
-        close $self->{fh} || die "Could not close file: $!";
+        flock($self->{fh}, LOCK_UN);
+        close $self->{fh} || die $!;
         $self->{opened} = 0;
     }
     
@@ -122,9 +106,10 @@ sub release_all_locks  {
     my $self    = shift;
     my $session = shift;
 
+    flock($self->{fh}, LOCK_UN);
+
     if ($self->{opened}) {
-        flock($self->{fh}, LOCK_UN) || die "Cannot unlock: $!";
-        close $self->{fh} || die "Could not close file: $!";
+        close $self->{fh} || die $!;
     }
     
     $self->{opened} = 0;
@@ -145,25 +130,19 @@ sub clean {
 
     my $now = time();
     
-    opendir(DIR, $dir) || die "Could not open directory $dir: $!";
+    opendir(DIR, $dir) || die $!;
     my @files = readdir(DIR);
     foreach my $file (@files) {
         if ($file =~ /^Apache-Session.*\.lock$/) {
-            if ($now - (stat($dir.'/'.$file))[8] >= $time) {
-              if ($^O eq 'MSWin32') {
-                #Windows cannot unlink open file
-                unlink($dir.'/'.$file) || next;
-              } else {
+            if ((stat($dir.'/'.$file))[8] - $now >= $time) {
                 open(FH, "+>$dir/".$file) || next;
                 flock(FH, LOCK_EX) || next;
                 unlink($dir.'/'.$file) || next;
                 flock(FH, LOCK_UN);
                 close(FH);
-              }
             }
         }
-    }
-    closedir(DIR);
+    }       
 }
 
 1;
@@ -207,10 +186,8 @@ If you do not supply this argument, temporary files will be created in /tmp.
 
 =head1 NOTES
 
-=head2 clean
-
 This module does not unlink temporary files, because it interferes with proper
-locking.  This can cause problems on certain systems (Linux) whose file systems
+locking.  THis can cause problems on certain systems (Linux) whose file systems
 (ext2) do not perform well with lots of files in one directory.  To prevent this
 you should use a script to clean out old files from your lock directory.
 The meaning of old is left as a policy decision for the implementor, but a
@@ -221,22 +198,6 @@ Example:
  my $l = new Apache::Session::Lock::File;
  $l->clean('/var/lock/sessions', 3600) #remove files older than 1 hour
 
-=head2 acquire_read_lock
-
-Will do nothing if write lock is in effect, only set readlock flag to true.
-
-=head2 release_read_lock
-
-Will do nothing if write lock is in effect, only set readlock flag to false.
-
-=head2 Win32 and Cygwin
-
-Windows cannot escalate lock, so all locks will be exclusive.
-
-release_read_lock not supported - it is not used by Apache::Session.
-
-When deleting files, they are not locked (Win32 only).
-
 =head1 AUTHOR
 
 This module was written by Jeffrey William Baker <jwbaker@acm.org>.
