@@ -2,7 +2,7 @@
 #
 # Apache::Session::Store::File
 # Implements session object storage via flat files
-# Copyright(c) 1998, 1999, 2000, 2004 Jeffrey William Baker (jwbaker@acm.org)
+# Copyright(c) 1998, 1999, 2000 Jeffrey William Baker (jwbaker@acm.org)
 # Distribute under the Artistic License
 #
 ############################################################################
@@ -14,7 +14,7 @@ use Symbol;
 use Fcntl;
 use vars qw($VERSION);
 
-$VERSION = '1.03';
+$VERSION = '1.00';
 
 $Apache::Session::Store::File::Directory = '/tmp';
 
@@ -38,9 +38,8 @@ sub insert {
         die "Object already exists in the data store";
     }
     
-    my $file = $directory.'/'.$session->{data}->{_session_id};
-    sysopen ($self->{fh}, $file, O_RDWR|O_CREAT) ||
-        die "Could not open file $file: $!";
+    sysopen ($self->{fh}, $directory.'/'.$session->{data}->{_session_id}, O_RDWR|O_CREAT) ||
+        die "Could not open file: $!";
 
     $self->{opened} = 1;
     
@@ -54,10 +53,9 @@ sub update {
     my $directory = $session->{args}->{Directory} || $Apache::Session::Store::File::Directory;
 
     if (!$self->{opened}) {
-        my $file = $directory.'/'.$session->{data}->{_session_id};
-        sysopen ($self->{fh}, $file, O_RDWR|O_CREAT) ||
-            die "Could not open file $file: $!";
-
+        sysopen ($self->{fh}, $directory.'/'.$session->{data}->{_session_id}, O_RDWR|O_CREAT) ||
+            die "Could not open file: $!";
+        
         $self->{opened} = 1;
     }
     
@@ -72,11 +70,10 @@ sub materialize {
     
     my $directory = $session->{args}->{Directory} || $Apache::Session::Store::File::Directory;
     
-    my $file = $directory.'/'.$session->{data}->{_session_id};
-    if (-e $file) {
+    if (-e $directory.'/'.$session->{data}->{_session_id}) {
         if (!$self->{opened}) {
-            sysopen ($self->{fh}, $file, O_RDWR|O_CREAT) ||
-                die "Could not open file $file: $!";
+            sysopen ($self->{fh}, $directory.'/'.$session->{data}->{_session_id}, O_RDWR|O_CREAT) ||
+                die "Could not open file: $!";
 
             $self->{opened} = 1;
         }
@@ -101,34 +98,24 @@ sub remove {
     my $directory = $session->{args}->{Directory} || $Apache::Session::Store::File::Directory;
 
     if ($self->{opened}) {
-        CORE::close $self->{fh};
+        close $self->{fh};
         $self->{opened} = 0;
     }
 
-    my $file = $directory.'/'.$session->{data}->{_session_id};
-    if (-e $file) {
-        unlink ($file) ||
-            die "Could not remove file $file: $!";
+    if (-e $directory.'/'.$session->{data}->{_session_id}) {
+        unlink ($directory.'/'.$session->{data}->{_session_id}) ||
+            die "Could not remove file: $!";
     }
     else {
         die "Object does not exist in the data store";
     }
 }
 
-sub close {
-    my $self = shift;
-    
-    if ($self->{opened}) {
-        CORE::close $self->{fh};
-        $self->{opened} = 0;
-    }
-}
-
 sub DESTROY {
     my $self = shift;
     
     if ($self->{opened}) {    
-        CORE::close $self->{fh};
+        close $self->{fh};
     }
 }
 
@@ -144,9 +131,9 @@ Apache::Session::Store::File - Store persistent data on the filesystem
 
 
  use Apache::Session::Store::File;
-
+ 
  my $store = new Apache::Session::Store::File;
-
+ 
  $store->insert($ref);
  $store->update($ref);
  $store->materialize($ref);
